==> franchise_service-tomato.20190109.021427-17-sources.jar: com/jz/jar/franchise/wrapper/ContractWrapper.java <==
package com.jz.jar.franchise.wrapper;

import java.util.Collection;
import java.util.List;

import com.jz.jooq.franchise.tables.pojos.Contract;
import com.jz.jooq.franchise.tables.pojos.ContractDetail;

public class ContractWrapper {

	private String contractId;
	private String serialNum; // 流水号
	private ParentWrapper parent;//
	private Integer type;
	private CoursePackWrapper coursePack;//
	private Collection<CourseWrapper> courses;
	private Integer totalPrice;
	private Integer materialFee;
	private Integer totalDiscount;
	private Integer deposit;
	private Integer finalFee;
	private Integer totalOfficalLesson;
	private Integer totalExtraLesson;
	private Double onePrice;
	private Long startTime;
	private Long endTime;
	private Integer status;
	private UserSimpleWrapper adviser;//
	private UserSimpleWrapper adviser2;//
	private Integer adviser2Rat;//
	private UserSimpleWrapper teacher;//
	private UserSimpleWrapper teacher2;
	private UserSimpleWrapper market;//
	private String remark;
	private Long created;
	private Long payTime;
	private UserPhoneWrapper introYg; //
	private StudentWrapper introHy; //
	private List<ContractStudentWrapper> students;

	private String relContractId;
	private List<ContractWrapper> relContracts;

	// detail信息，只有获取详情的时候才会获取
	private String faName;
	private String faPhone;
	private String faEmail;
	private String faCompany;
	private String moName;
	private String moPhone;
	private String moEmail;
	private String moCompany;
	private String address;
	private String receiptCode;
	private String paymentMode;
	private String giftId;
	private String giftName;
	private Integer giftValue;

	// 是否可以退款和退订金
	private Boolean refundAble;
	private Boolean refundDepositAble;
	private Boolean printNoteAble;
	private Boolean postponeAble;

	private String originChannelId;
	private String originChannelName;

	private String contractChannelId;
	private String contractChannelName;

	private List<ContractPostponeWrapper> postpones;

	private int noScheduleOfficalLesson;
	private int consumeOfficalLesson;

	public static ContractWrapper of(Contract c) {
		return new ContractWrapper().setContractId(c.getContractId()).setType(c.getType())
				.setTotalPrice(c.getTotalPrice()).setMaterialFee(c.getMaterialFee()).setDeposit(c.getDeposit())
				.setFinalFee(c.getFinalFee()).setTotalOfficalLesson(c.getTotalOfficalLesson())
				.setTotalExtraLesson(c.getTotalExtraLesson()).setOnePrice(c.getOnePrice().doubleValue())
				.setStartTime(c.getStartTime()).setEndTime(c.getEndTime()).setStatus(c.getStatus())
				.setRemark(c.getRemark()).setCreated(c.getCreated()).setPayTime(c.getPayTime())
				.setRelContractId(c.getRelContract())
				.setTotalDiscount(c.getTotalPrice() + c.getMaterialFee() - c.getFinalFee());
	}

	public ContractWrapper setContractDetail(ContractDetail cd) {
		return this.setFaName(cd.getFaName()).setFaPhone(cd.getFaPhone()).setFaEmail(cd.getFaEmail())
				.setFaCompany(cd.getFaCompany()).setMoName(cd.getMoName()).setMoPhone(cd.getMoPhone())
				.setMoEmail(cd.getMoEmail()).setMoCompany(cd.getMoCompany()).setAddress(cd.getAddress())
				.setReceiptCode(cd.getReceiptCode()).setPaymentMode(cd.getPaymentMode()).setGiftId(cd.getGiftId())
				.setGiftName(cd.getGiftName()).setGiftValue(cd.getGiftValue());
	}

	public String getContractId() {
		return contractId;
	}

	public ContractWrapper setContractId(String contractId) {
		this.contractId = contractId;
		return this;
	}

	public ParentWrapper getParent() {
		return parent;
	}

	public ContractWrapper setParent(ParentWrapper parent) {
		this.parent = parent;
		return this;
	}

	public Integer getType() {
		return type;
	}

	public ContractWrapper setType(Integer type) {
		this.type = type;
		return this;
	}

	public CoursePackWrapper getCoursePack() {
		return coursePack;
	}

	public ContractWrapper setCoursePack(CoursePackWrapper coursePack) {
		this.coursePack = coursePack;
		return this;
	}

	public Integer getTotalPrice() {
		return totalPrice;
	}

	public ContractWrapper setTotalPrice(Integer totalPrice) {
		this.totalPrice = totalPrice;
		return this;
	}

	public Integer getMaterialFee() {
		return materialFee;
	}

	public ContractWrapper setMaterialFee(Integer materialFee) {
		this.materialFee = materialFee;
		return this;
	}

	public Integer getDeposit() {
		return deposit;
	}

	public ContractWrapper setDeposit(Integer deposit) {
		this.deposit = deposit;
		return this;
	}

	public Integer getFinalFee() {
		return finalFee;
	}

	public ContractWrapper setFinalFee(Integer finalFee) {
		this.finalFee = finalFee;
		return this;
	}

	public Integer getTotalOfficalLesson() {
		return totalOfficalLesson;
	}

	public ContractWrapper setTotalOfficalLesson(Integer totalOfficalLesson) {
		this.totalOfficalLesson = totalOfficalLesson;
		return this;
	}

	public Integer getTotalExtraLesson() {
		return totalExtraLesson;
	}

	public ContractWrapper setTotalExtraLesson(Integer totalExtraLesson) {
		this.totalExtraLesson = totalExtraLesson;
		return this;
	}

	public Double getOnePrice() {
		return onePrice;
	}

	public ContractWrapper setOnePrice(Double onePrice) {
		this.onePrice = onePrice;
		return this;
	}

	public Long getStartTime() {
		return startTime;
	}

	public ContractWrapper setStartTime(Long startTime) {
		this.startTime = startTime;
		return this;
	}

	public Long getEndTime() {
		return endTime;
	}

	public ContractWrapper setEndTime(Long endTime) {
		this.endTime = endTime;
		return this;
	}

	public Integer getStatus() {
		return status;
	}

	public ContractWrapper setStatus(Integer status) {
		this.status = status;
		return this;
	}

	public UserSimpleWrapper getAdviser() {
		return adviser;
	}

	public ContractWrapper setAdviser(UserSimpleWrapper adviser) {
		this.adviser = adviser;
		return this;
	}

	public UserSimpleWrapper getTeacher() {
		return teacher;
	}

	public ContractWrapper setTeacher(UserSimpleWrapper teacher) {
		this.teacher = teacher;
		return this;
	}

	public UserSimpleWrapper getMarket() {
		return market;
	}

	public ContractWrapper setMarket(UserSimpleWrapper market) {
		this.market = market;
		return this;
	}

	public Long getCreated() {
		return created;
	}

	public ContractWrapper setCreated(Long created) {
		this.created = created;
		return this;
	}

	public List<ContractStudentWrapper> getStudents() {
		return students;
	}

	public ContractWrapper setStudents(List<ContractStudentWrapper> students) {
		this.students = students;
		return this;
	}

	public String getRemark() {
		return remark;
	}

	public ContractWrapper setRemark(String remark) {
		this.remark = remark;
		return this;
	}

	public String getFaName() {
		return faName;
	}

	public ContractWrapper setFaName(String faName) {
		this.faName = faName;
		return this;
	}

	public String getFaPhone() {
		return faPhone;
	}

	public ContractWrapper setFaPhone(String faPhone) {
		this.faPhone = faPhone;
		return this;
	}

	public String getFaEmail() {
		return faEmail;
	}

	public ContractWrapper setFaEmail(String faEmail) {
		this.faEmail = faEmail;
		return this;
	}

	public String getFaCompany() {
		return faCompany;
	}

	public ContractWrapper setFaCompany(String faCompany) {
		this.faCompany = faCompany;
		return this;
	}

	public String getMoName() {
		return moName;
	}

	public ContractWrapper setMoName(String moName) {
		this.moName = moName;
		return this;
	}

	public String getMoPhone() {
		return moPhone;
	}

	public ContractWrapper setMoPhone(String moPhone) {
		this.moPhone = moPhone;
		return this;
	}

	public String getMoEmail() {
		return moEmail;
	}

	public ContractWrapper setMoEmail(String moEmail) {
		this.moEmail = moEmail;
		return this;
	}

	public String getMoCompany() {
		return moCompany;
	}

	public ContractWrapper setMoCompany(String moCompany) {
		this.moCompany = moCompany;
		return this;
	}

	public String getAddress() {
		return address;
	}

	public ContractWrapper setAddress(String address) {
		this.address = address;
		return this;
	}

	public String getReceiptCode() {
		return receiptCode;
	}

	public ContractWrapper setReceiptCode(String receiptCode) {
		this.receiptCode = receiptCode;
		return this;
	}

	public String getPaymentMode() {
		return paymentMode;
	}

	public ContractWrapper setPaymentMode(String paymentMode) {
		this.paymentMode = paymentMode;
		return this;
	}

	public String getGiftName() {
		return giftName;
	}

	public ContractWrapper setGiftName(String giftName) {
		this.giftName = giftName;
		return this;
	}

	public Integer getGiftValue() {
		return giftValue;
	}

	public ContractWrapper setGiftValue(Integer giftValue) {
		this.giftValue = giftValue;
		return this;
	}

	public Boolean getRefundAble() {
		return refundAble;
	}

	public ContractWrapper setRefundAble(Boolean refundAble) {
		this.refundAble = refundAble;
		return this;
	}

	public Boolean getRefundDepositAble() {
		return refundDepositAble;
	}

	public ContractWrapper setRefundDepositAble(Boolean refundDepositAble) {
		this.refundDepositAble = refundDepositAble;
		return this;
	}

	public Collection<CourseWrapper> getCourses() {
		return courses;
	}

	public ContractWrapper setCourses(Collection<CourseWrapper> courses) {
		this.courses = courses;
		return this;
	}

	public Long getPayTime() {
		return payTime;
	}

	public ContractWrapper setPayTime(Long payTime) {
		this.payTime = payTime;
		return this;
	}

	public Integer getTotalDiscount() {
		return totalDiscount;
	}

	public ContractWrapper setTotalDiscount(Integer totalDiscount) {
		this.totalDiscount = totalDiscount;
		return this;
	}

	public String getSerialNum() {
		return serialNum;
	}

	public ContractWrapper setSerialNum(String serialNum) {
		this.serialNum = serialNum;
		return this;
	}

	public Boolean getPrintNoteAble() {
		return printNoteAble;
	}

	public ContractWrapper setPrintNoteAble(Boolean printNoteAble) {
		this.printNoteAble = printNoteAble;
		return this;
	}

	public String getGiftId() {
		return giftId;
	}

	public ContractWrapper setGiftId(String giftId) {
		this.giftId = giftId;
		return this;
	}

	public UserSimpleWrapper getAdviser2() {
		return adviser2;
	}

	public ContractWrapper setAdviser2(UserSimpleWrapper adviser2) {
		this.adviser2 = adviser2;
		return this;
	}

	public Integer getAdviser2Rat() {
		return adviser2Rat;
	}

	public ContractWrapper setAdviser2Rat(Integer adviser2Rat) {
		this.adviser2Rat = adviser2Rat;
		return this;
	}

	public UserSimpleWrapper getTeacher2() {
		return teacher2;
	}

	public ContractWrapper setTeacher2(UserSimpleWrapper teacher2) {
		this.teacher2 = teacher2;
		return this;
	}

	public UserPhoneWrapper getIntroYg() {
		return introYg;
	}

	public ContractWrapper setIntroYg(UserPhoneWrapper introYg) {
		this.introYg = introYg;
		return this;
	}

	public StudentWrapper getIntroHy() {
		return introHy;
	}

	public ContractWrapper setIntroHy(StudentWrapper introHy) {
		this.introHy = introHy;
		return this;
	}

	public String getContractChannelId() {
		return contractChannelId;
	}

	public ContractWrapper setContractChannelId(String contractChannelId) {
		this.contractChannelId = contractChannelId;
		return this;
	}

	public String getContractChannelName() {
		return contractChannelName;
	}

	public ContractWrapper setContractChannelName(String contractChannelName) {
		this.contractChannelName = contractChannelName;
		return this;
	}

	public String getOriginChannelId() {
		return originChannelId;
	}

	public ContractWrapper setOriginChannelId(String originChannelId) {
		this.originChannelId = originChannelId;
		return this;
	}

	public String getOriginChannelName() {
		return originChannelName;
	}

	public ContractWrapper setOriginChannelName(String originChannelName) {
		this.originChannelName = originChannelName;
		return this;
	}

	public List<ContractPostponeWrapper> getPostpones() {
		return postpones;
	}

	public ContractWrapper setPostpones(List<ContractPostponeWrapper> postpones) {
		this.postpones = postpones;
		return this;
	}

	public Boolean getPostponeAble() {
		return postponeAble;
	}

	public ContractWrapper setPostponeAble(Boolean postponeAble) {
		this.postponeAble = postponeAble;
		return this;
	}

	public int getNoScheduleOfficalLesson() {
		return noScheduleOfficalLesson;
	}

	public ContractWrapper setNoScheduleOfficalLesson(int noScheduleOfficalLesson) {
		this.noScheduleOfficalLesson = noScheduleOfficalLesson;
		return this;
	}

	public int getConsumeOfficalLesson() {
		return consumeOfficalLesson;
	}

	public ContractWrapper setConsumeOfficalLesson(int consumeOfficalLesson) {
		this.consumeOfficalLesson = consumeOfficalLesson;
		return this;
	}

	public String getRelContractId() {
		return relContractId;
	}

	public ContractWrapper setRelContractId(String relContractId) {
		this.relContractId = relContractId;
		return this;
	}

	public List<ContractWrapper> getRelContracts() {
		return relContracts;
	}

	public ContractWrapper setRelContracts(List<ContractWrapper> relContracts) {
		this.relContracts = relContracts;
		return this;
	}

}

==> franchise_service-tomato.20190129.024150-99-sources.jar: com/jz/jar/franchise/wrapper/ContractWrapper.java <==
package com.jz.jar.franchise.wrapper;

import java.util.Collection;
import java.util.List;

import com.jz.jooq.franchise.tables.pojos.Contract;
import com.jz.jooq.franchise.tables.pojos.ContractDetail;

public class ContractWrapper {

	private String contractId;
	private String serialNum; // 流水号
	private ParentWrapper parent;//
	private Integer type;
	private CoursePackWrapper coursePack;//
	private Collection<CourseWrapper> courses;
	private Integer totalPrice;
	private Integer materialFee;
	private Integer totalDiscount;
	private Integer deposit;
	private Integer finalFee;
	private Integer totalOfficalLesson;
	private Integer totalExtraLesson;
	private Double onePrice;
	private Long startTime;
	private Long endTime;
	private Integer status;
	private UserSimpleWrapper adviser;//
	private UserSimpleWrapper adviser2;//
	private Integer adviser2Rat;//
	private UserSimpleWrapper teacher;//
	private UserSimpleWrapper teacher2;
	private UserSimpleWrapper market;//
	private String remark;
	private Long created;
	private Long payTime;
	private UserPhoneWrapper introYg; //
	private StudentWrapper introHy; //
	private List<ContractStudentWrapper> students;

	private String relContractId;
	private List<ContractWrapper> relContracts;

	// detail信息，只有获取详情的时候才会获取
	private String faName;
	private String faPhone;
	private String faEmail;
	private String faCompany;
	private String moName;
	private String moPhone;
	private String moEmail;
	private String moCompany;
	private String address;
	private String receiptCode;
	private String paymentMode;
	private String giftId;
	private String giftName;
	private Integer giftValue;

	// 是否可以退款和退订金
	private Boolean refundAble;
	private Boolean refundDepositAble;
	private Boolean printNoteAble;
	private Boolean postponeAble;

	private String originChannelId;
	private String originChannelName;

	private String contractChannelId;
	private String contractChannelName;

	private List<ContractPostponeWrapper> postpones;

	private int noScheduleOfficalLesson;
	private int consumeOfficalLesson;

	// 已完结合同
	private Boolean isFinished;

	public static ContractWrapper of(Contract c) {
		return new ContractWrapper().setContractId(c.getContractId()).setType(c.getType())
				.setTotalPrice(c.getTotalPrice()).setMaterialFee(c.getMaterialFee()).setDeposit(c.getDeposit())
				.setFinalFee(c.getFinalFee()).setTotalOfficalLesson(c.getTotalOfficalLesson())
				.setTotalExtraLesson(c.getTotalExtraLesson()).setOnePrice(c.getOnePrice().doubleValue())
				.setStartTime(c.getStartTime()).setEndTime(c.getEndTime()).setStatus(c.getStatus())
				.setRemark(c.getRemark()).setCreated(c.getCreated()).setPayTime(c.getPayTime())
				.setRelContractId(c.getRelContract())
				.setTotalDiscount(c.getTotalPrice() + c.getMaterialFee() - c.getFinalFee());
	}

	public ContractWrapper setContractDetail(ContractDetail cd) {
		return this.setFaName(cd.getFaName()).setFaPhone(cd.getFaPhone()).setFaEmail(cd.getFaEmail())
				.setFaCompany(cd.getFaCompany()).setMoName(cd.getMoName()).setMoPhone(cd.getMoPhone())
				.setMoEmail(cd.getMoEmail()).setMoCompany(cd.getMoCompany()).setAddress(cd.getAddress())
				.setReceiptCode(cd.getReceiptCode()).setPaymentMode(cd.getPaymentMode()).setGiftId(cd.getGiftId())
				.setGiftName(cd.getGiftName()).setGiftValue(cd.getGiftValue());
	}

	public String getContractId() {
		return contractId;
	}

	public ContractWrapper setContractId(String contractId) {
		this.contractId = contractId;
		return this;
	}

	public ParentWrapper getParent() {
		return parent;
	}

	public ContractWrapper setParent(ParentWrapper parent) {
		this.parent = parent;
		return this;
	}

	public Integer getType() {
		return type;
	}

	public ContractWrapper setType(Integer type) {
		this.type = type;
		return this;
	}

	public CoursePackWrapper getCoursePack() {
		return coursePack;
	}

	public ContractWrapper setCoursePack(CoursePackWrapper coursePack) {
		this.coursePack = coursePack;
		return this;
	}

	public Integer getTotalPrice() {
		return totalPrice;
	}

	public ContractWrapper setTotalPrice(Integer totalPrice) {
		this.totalPrice = totalPrice;
		return this;
	}

	public Integer getMaterialFee() {
		return materialFee;
	}

	public ContractWrapper setMaterialFee(Integer materialFee) {
		this.materialFee = materialFee;
		return this;
	}

	public Integer getDeposit() {
		return deposit;
	}

	public ContractWrapper setDeposit(Integer deposit) {
		this.deposit = deposit;
		return this;
	}

	public Integer getFinalFee() {
		return finalFee;
	}

	public ContractWrapper setFinalFee(Integer finalFee) {
		this.finalFee = finalFee;
		return this;
	}

	public Integer getTotalOfficalLesson() {
		return totalOfficalLesson;
	}

	public ContractWrapper setTotalOfficalLesson(Integer totalOfficalLesson) {
		this.totalOfficalLesson = totalOfficalLesson;
		return this;
	}

	public Integer getTotalExtraLesson() {
		return totalExtraLesson;
	}

	public ContractWrapper setTotalExtraLesson(Integer totalExtraLesson) {
		this.totalExtraLesson = totalExtraLesson;
		return this;
	}

	public Double getOnePrice() {
		return onePrice;
	}

	public ContractWrapper setOnePrice(Double onePrice) {
		this.onePrice = onePrice;
		return this;
	}

	public Long getStartTime() {
		return startTime;
	}

	public ContractWrapper setStartTime(Long startTime) {
		this.startTime = startTime;
		return this;
	}

	public Long getEndTime() {
		return endTime;
	}

	public ContractWrapper setEndTime(Long endTime) {
		this.endTime = endTime;
		return this;
	}

	public Integer getStatus() {
		return status;
	}

	public ContractWrapper setStatus(Integer status) {
		this.status = status;
		return this;
	}

	public UserSimpleWrapper getAdviser() {
		return adviser;
	}

	public ContractWrapper setAdviser(UserSimpleWrapper adviser) {
		this.adviser = adviser;
		return this;
	}

	public UserSimpleWrapper getTeacher() {
		return teacher;
	}

	public ContractWrapper setTeacher(UserSimpleWrapper teacher) {
		this.teacher = teacher;
		return this;
	}

	public UserSimpleWrapper getMarket() {
		return market;
	}

	public ContractWrapper setMarket(UserSimpleWrapper market) {
		this.market = market;
		return this;
	}

	public Long getCreated() {
		return created;
	}

	public ContractWrapper setCreated(Long created) {
		this.created = created;
		return this;
	}

	public List<ContractStudentWrapper> getStudents() {
		return students;
	}

	public ContractWrapper setStudents(List<ContractStudentWrapper> students) {
		this.students = students;
		return this;
	}

	public String getRemark() {
		return remark;
	}

	public ContractWrapper setRemark(String remark) {
		this.remark = remark;
		return this;
	}

	public String getFaName() {
		return faName;
	}

	public ContractWrapper setFaName(String faName) {
		this.faName = faName;
		return this;
	}

	public String getFaPhone() {
		return faPhone;
	}

	public ContractWrapper setFaPhone(String faPhone) {
		this.faPhone = faPhone;
		return this;
	}

	public String getFaEmail() {
		return faEmail;
	}

	public ContractWrapper setFaEmail(String faEmail) {
		this.faEmail = faEmail;
		return this;
	}

	public String getFaCompany() {
		return faCompany;
	}

	public ContractWrapper setFaCompany(String faCompany) {
		this.faCompany = faCompany;
		return this;
	}

	public String getMoName() {
		return moName;
	}

	public ContractWrapper setMoName(String moName) {
		this.moName = moName;
		return this;
	}

	public String getMoPhone() {
		return moPhone;
	}

	public ContractWrapper setMoPhone(String moPhone) {
		this.moPhone = moPhone;
		return this;
	}

	public String getMoEmail() {
		return moEmail;
	}

	public ContractWrapper setMoEmail(String moEmail) {
		this.moEmail = moEmail;
		return this;
	}

	public String getMoCompany() {
		return moCompany;
	}

	public ContractWrapper setMoCompany(String moCompany) {
		this.moCompany = moCompany;
		return this;
	}

	public String getAddress() {
		return address;
	}

	public ContractWrapper setAddress(String address) {
		this.address = address;
		return this;
	}

	public String getReceiptCode() {
		return receiptCode;
	}

	public ContractWrapper setReceiptCode(String receiptCode) {
		this.receiptCode = receiptCode;
		return this;
	}

	public String getPaymentMode() {
		return paymentMode;
	}

	public ContractWrapper setPaymentMode(String paymentMode) {
		this.paymentMode = paymentMode;
		return this;
	}

	public String getGiftName() {
		return giftName;
	}

	public ContractWrapper setGiftName(String giftName) {
		this.giftName = giftName;
		return this;
	}

	public Integer getGiftValue() {
		return giftValue;
	}

	public ContractWrapper setGiftValue(Integer giftValue) {
		this.giftValue = giftValue;
		return this;
	}

	public Boolean getRefundAble() {
		return refundAble;
	}

	public ContractWrapper setRefundAble(Boolean refundAble) {
		this.refundAble = refundAble;
		return this;
	}

	public Boolean getRefundDepositAble() {
		return refundDepositAble;
	}

	public ContractWrapper setRefundDepositAble(Boolean refundDepositAble) {
		this.refundDepositAble = refundDepositAble;
		return this;
	}

	public Collection<CourseWrapper> getCourses() {
		return courses;
	}

	public ContractWrapper setCourses(Collection<CourseWrapper> courses) {
		this.courses = courses;
		return this;
	}

	public Long getPayTime() {
		return payTime;
	}

	public ContractWrapper setPayTime(Long payTime) {
		this.payTime = payTime;
		return this;
	}

	public Integer getTotalDiscount() {
		return totalDiscount;
	}

	public ContractWrapper setTotalDiscount(Integer totalDiscount) {
		this.totalDiscount = totalDiscount;
		return this;
	}

	public String getSerialNum() {
		return serialNum;
	}

	public ContractWrapper setSerialNum(String serialNum) {
		this.serialNum = serialNum;
		return this;
	}

	public Boolean getPrintNoteAble() {
		return printNoteAble;
	}

	public ContractWrapper setPrintNoteAble(Boolean printNoteAble) {
		this.printNoteAble = printNoteAble;
		return this;
	}

	public String getGiftId() {
		return giftId;
	}

	public ContractWrapper setGiftId(String giftId) {
		this.giftId = giftId;
		return this;
	}

	public UserSimpleWrapper getAdviser2() {
		return adviser2;
	}

	public ContractWrapper setAdviser2(UserSimpleWrapper adviser2) {
		this.adviser2 = adviser2;
		return this;
	}

	public Integer getAdviser2Rat() {
		return adviser2Rat;
	}

	public ContractWrapper setAdviser2Rat(Integer adviser2Rat) {
		this.adviser2Rat = adviser2Rat;
		return this;
	}

	public UserSimpleWrapper getTeacher2() {
		return teacher2;
	}

	public ContractWrapper setTeacher2(UserSimpleWrapper teacher2) {
		this.teacher2 = teacher2;
		return this;
	}

	public UserPhoneWrapper getIntroYg() {
		return introYg;
	}

	public ContractWrapper setIntroYg(UserPhoneWrapper introYg) {
		this.introYg = introYg;
		return this;
	}

	public StudentWrapper getIntroHy() {
		return introHy;
	}

	public ContractWrapper setIntroHy(StudentWrapper introHy) {
		this.introHy = introHy;
		return this;
	}

	public String getContractChannelId() {
		return contractChannelId;
	}

	public ContractWrapper setContractChannelId(String contractChannelId) {
		this.contractChannelId = contractChannelId;
		return this;
	}

	public String getContractChannelName() {
		return contractChannelName;
	}

	public ContractWrapper setContractChannelName(String contractChannelName) {
		this.contractChannelName = contractChannelName;
		return this;
	}

	public String getOriginChannelId() {
		return originChannelId;
	}

	public ContractWrapper setOriginChannelId(String originChannelId) {
		this.originChannelId = originChannelId;
		return this;
	}

	public String getOriginChannelName() {
		return originChannelName;
	}

	public ContractWrapper setOriginChannelName(String originChannelName) {
		this.originChannelName = originChannelName;
		return this;
	}

	public List<ContractPostponeWrapper> getPostpones() {
		return postpones;
	}

	public ContractWrapper setPostpones(List<ContractPostponeWrapper> postpones) {
		this.postpones = postpones;
		return this;
	}

	public Boolean getPostponeAble() {
		return postponeAble;
	}

	public ContractWrapper setPostponeAble(Boolean postponeAble) {
		this.postponeAble = postponeAble;
		return this;
	}

	public int getNoScheduleOfficalLesson() {
		return noScheduleOfficalLesson;
	}

	public ContractWrapper setNoScheduleOfficalLesson(int noScheduleOfficalLesson) {
		this.noScheduleOfficalLesson = noScheduleOfficalLesson;
		return this;
	}

	public int getConsumeOfficalLesson() {
		return consumeOfficalLesson;
	}

	public ContractWrapper setConsumeOfficalLesson(int consumeOfficalLesson) {
		this.consumeOfficalLesson = consumeOfficalLesson;
		return this;
	}

	public String getRelContractId() {
		return relContractId;
	}

	public ContractWrapper setRelContractId(String relContractId) {
		this.relContractId = relContractId;
		return this;
	}

	public List<ContractWrapper> getRelContracts() {
		return relContracts;
	}

	public ContractWrapper setRelContracts(List<ContractWrapper> relContracts) {
		this.relContracts = relContracts;
		return this;
	}

	public Boolean getIsFinished() {
		return isFinished;
	}

	public ContractWrapper setIsFinished(Boolean isFinished) {
		this.isFinished = isFinished;
		return this;
	}

}
